@@ -1,11 +1,8 @@
-from pathlib import PurePath
-
 SERVER_URL = 'http://localhost:5000'
 WEB_URL = 'http://localhost:5000'
 SLACK_BOT_TOKEN = 'XXX'
 SLACK_CHANNEL = 'XXX'
 AUTH0_DOMAIN = 'XXX'
-DATA_PATH = PurePath('/xxx/xxx/data')
 SENTRY_DSN = 'XXX'
 FLOAT_PROJECT_TOKEN = 'XXXX'
 SAMPLES_PROJECT_TOKEN = 'XXX'
